@@ -1,3 +1,5 @@
 from .enricher import *
 from .enricher_builder import *
-from .elasticsearch_connector import *
\ No newline at end of file
+from .elasticsearch_connector import *
+from .osm import *
+from .sql_connector import *
